@@ -59,5 +59,13 @@ class Mosaic(ExtensionAppJinjaMixin, ExtensionApp):
 def main():
     Mosaic.launch_instance()
 
+
+def setup_pouchdb():
+    return {
+        # hardcode port for backend access
+        'command': ['pouchdb-server', '-p', '{port}'],
+        'port': 5984
+    }
+
 if __name__ == "__main__":
     main()
\ No newline at end of file
